/// <reference types="node" />
/** Handle a slash command interaction */
export declare class Interaction {
    /** The Discord developer portal application ID or bot client ID */
    applicationId: string;
    /** The defaults to use for the initial response */
    defaults: Partial<InteractionResponse>;
    /** Whether or not an initial response been sent */
    private sentInitial;
    /**
     * Construct an interaction client
     *
     * NOTE: when `applicationId` is not set, the application ID must be set in an environment variable called `APPLICATION_ID`
     * @param interaction The interaction data
     * @param [defaults] The default settings used when sending the initial response
     */
    constructor(interaction: Interaction, defaults?: Interaction['defaults']);
    /**
     * Construct an interaction client
     * @param interaction The interaction data
     * @param applicationId The ID of the application
     * @param [defaults] The default settings used when sending the initial response
     */
    constructor(interaction: Interaction, applicationId?: string, defaults?: Interaction['defaults']);
    /**
     * Send a plain text message
     * @param body Text to send
     */
    send<T extends WebhookPostResult | void>(body: string): Promise<T>;
    /**
     * Send an initial response
     *
     * note: you must do this before sending a followup message
     * @param body Initial response data
     */
    send(body: InteractionResponse): Promise<void>;
    /**
     * Send a followup message
     *
     * note: you can only use this after sending the initial response
     * @param body Followup message data
     */
    send(body: WebhookBody): Promise<WebhookPostResult>;
    /**
     * Edit an interaction response
     * @param body The new message content
     * @param [id] The ID to of the message to edit. Leave blank to edit original message
     */
    edit(body: WebhookBody | string, id?: string): Promise<WebhookPostResult>;
    /**
     * Delete a message
     * @param [id] The ID of the message to delete. Leave empty to delete original message.
     */
    delete(id?: string): Promise<void>;
    /** The full command that was used */
    toString(): string;
    /** The callback URL for sending an initial response */
    get callbackURL(): string;
    /** The webhook URL for sending followup messages */
    get webhookURL(): string;
    /** The full command that was used */
    get content(): string;
}
export interface ApplicationCommand {
    id: string;
    application_id: string;
    name: string;
    description: string;
    options?: ApplicationCommandOption[];
}
export interface ApplicationCommandOption {
    type: number;
    name: string;
    description: string;
    default?: boolean;
    required?: boolean;
    choices?: ApplicationCommandOptionChoice;
    options?: ApplicationCommandOption;
}
export declare enum ApplicationCommandOptionType {
    SUB_COMMAND = 1,
    SUB_COMMAND_GROUP = 2,
    STRING = 3,
    INTEGER = 4,
    BOOLEAN = 5,
    USER = 6,
    CHANNEL = 7,
    ROLE = 8
}
export interface ApplicationCommandOptionChoice {
    name: string;
    value: string | number;
}
export interface Interaction {
    id: string;
    type: InteractionType;
    data: ApplicationCommandInteractionData;
    guild_id: string;
    channel_id: string;
    member: GuildMember;
    token: string;
    version: number;
}
export declare enum InteractionType {
    Ping = 1,
    ApplicationCommand = 2
}
export interface ApplicationCommandInteractionData {
    id: string;
    name: string;
    options?: ApplicationCommandInteractionDataOption[];
}
export declare type ApplicationCommandInteractionDataOption = {
    name: string;
    options: ApplicationCommandInteractionDataOption[];
    value?: never;
} | {
    name: string;
    options?: never;
    value: string | number | boolean;
};
export interface InteractionResponse {
    type: InteractionResponseType;
    data?: InteractionApplicationCommandCallbackData;
}
export declare enum InteractionResponseType {
    Pong = 1,
    Acknowledge = 2,
    ChannelMessage = 3,
    ChannelMessageWithSource = 4,
    ACKWithSource = 5
}
export declare type ResponseType = InteractionResponseType | keyof typeof InteractionResponseType;
export declare enum InteractionResponseFlags {
    EPHEMERAL = 64
}
export declare type ResponseFlags = InteractionResponseFlags | keyof typeof InteractionResponseFlags;
export interface InteractionApplicationCommandCallbackData {
    tts?: boolean;
    content?: string;
    flags?: InteractionResponseFlags;
    embeds?: EmbedJSON[];
    allowed_mentions?: AllowedMentions;
}
export interface GuildMember {
    deaf: boolean;
    is_pending: boolean;
    joined_at: Date;
    mute: boolean;
    nick: string;
    pending: boolean;
    permissions: string;
    premium_since: Date | null;
    roles: string[];
    user: User;
}
export interface User {
    avatar: string;
    discriminator: string;
    id: string;
    public_flags: number;
    username: string;
}
export interface EmbedJSON {
    title?: string;
    type?: 'rich' | 'image' | 'video' | 'gifv' | 'article' | 'link';
    description?: string;
    url?: string;
    timestamp?: Date | number;
    color?: number;
    footer?: {
        text: string;
        icon_url?: string;
        proxy_icon_url?: string;
    };
    image?: {
        url?: string;
        proxy_url?: string;
        height?: number;
        width?: number;
    };
    thumbnail?: {
        url?: string;
        proxy_url?: string;
        height?: number;
        width?: number;
    };
    video?: {
        url?: string;
        height?: number;
        width?: number;
    };
    provider?: {
        name?: string;
        url?: string;
    };
    author?: {
        name?: string;
        url?: string;
        icon_url?: string;
        proxy_icon_url?: string;
    };
    fields?: {
        name: string;
        value: string;
        inline?: boolean;
    }[];
}
export interface AllowedMentions {
    parse?: ('roles' | 'users' | 'everyone')[];
    roles?: string[];
    users?: string[];
    replied_user?: boolean;
}
export interface WebhookBody {
    username?: string;
    content?: string;
    avatar_url?: string;
    tts?: boolean;
    file?: Buffer;
    embeds?: EmbedJSON[];
    allowed_mentions?: AllowedMentions;
}
export interface WebhookPostResult {
    id: string;
    type: number;
    content: string;
    author: {
        bot: boolean;
        id: string;
        username: string;
        discriminator: string;
        avatar: string | null;
    };
    attachments: {
        id: string;
        filename: string;
        size: number;
        url: string;
        proxy_url: string;
        height: number | null;
        width: number | null;
    }[];
    embeds: EmbedJSON[];
    mentions: string[];
    mention_roles: string[];
    pinned: boolean;
    mention_everyone: boolean;
    tts: boolean;
    timestamp: string;
    edited_timestamp: string | null;
    flags: number;
    webhook_id: string;
}
